VdirClientError

Enum VdirClientError 

pub enum VdirClientError {
Show 14 variants VdirCollectionCreate(VdirCollectionCreateError), VdirCollectionDelete(VdirCollectionDeleteError), VdirCollectionList(VdirCollectionListError), VdirCollectionRename(VdirCollectionRenameError), VdirCollectionUpdate(VdirCollectionUpdateError), VdirItemLocate(VdirItemLocateError), VdirItemGet(VdirItemGetError), VdirItemList(VdirItemListError), VdirItemStore(VdirItemStoreError), VdirItemCopy(VdirItemCopyError), VdirItemMove(VdirItemMoveError), VdirItemDelete(VdirItemDeleteError), Io(Error), Random(Error),
}
Available on crate feature client only.
Errors returned by the VdirClient helpers.

Variants



VdirCollectionCreate(VdirCollectionCreateError)

A collection create coroutine failed.



VdirCollectionDelete(VdirCollectionDeleteError)

A collection delete coroutine failed.



VdirCollectionList(VdirCollectionListError)

A collection list coroutine failed.



VdirCollectionRename(VdirCollectionRenameError)

A collection rename coroutine failed.



VdirCollectionUpdate(VdirCollectionUpdateError)

A collection update coroutine failed.



VdirItemLocate(VdirItemLocateError)

An item locate coroutine failed.



VdirItemGet(VdirItemGetError)

An item get coroutine failed.



VdirItemList(VdirItemListError)

An item list coroutine failed.



VdirItemStore(VdirItemStoreError)

An item store coroutine failed.



VdirItemCopy(VdirItemCopyError)

An item copy coroutine failed.



VdirItemMove(VdirItemMoveError)

An item move coroutine failed.



VdirItemDelete(VdirItemDeleteError)

An item delete coroutine failed.



Io(Error)

A filesystem operation failed while servicing a coroutine request.



Random(Error)

The system entropy source failed while minting a new item id.