pub struct VdirCollectionList { /* private fields */ }Expand description
Lists every Vdir collection directly under a root directory.
Implementations
Sourceimpl VdirCollectionList
impl VdirCollectionList
Sourcepub fn new(root: impl Into<VdirPath>, opts: VdirCollectionListOptions) -> Self
pub fn new(root: impl Into<VdirPath>, opts: VdirCollectionListOptions) -> Self
Creates a new coroutine that will list collections inside
root.