pub struct VdirCollection {
pub path: VdirPath,
pub display_name: Option<String>,
pub description: Option<String>,
pub color: Option<String>,
}Expand description
A Vdir collection.
Represents a directory that contains only items (vCard or iCalendar files). A collection may also carry the optional metadata files defined by the vdir specification.
Fields
path: VdirPathOn-disk directory of the collection.
display_name: Option<String>Display name of the collection, when the displayname file
exists and is non-empty.
description: Option<String>Description of the collection, when the description file
exists and is non-empty.
color: Option<String>ASCII #RRGGBB hex color of the collection, when the color
file exists and is non-empty.
Implementations