VdirItemMove

Struct VdirItemMove 

pub struct VdirItemMove { /* private fields */ }
Moves a Vdir item from a source into a target collection.

Implementations

Source

impl VdirItemMove

pub fn new( source: impl Into<VdirPath>, target: impl Into<VdirPath>, id: impl ToString, opts: VdirItemMoveOptions, ) -> Self

Creates a new coroutine that will move item id from source into target. The item keeps the same id and extension in the target collection.